@@ -365,19 +365,13 @@ def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
             if channel_type == v4c.CHANNEL_TYPE_VALUE:
                 fmt = f"({size},)u1"
             else:
-                if size == 4:
-                    fmt = "<u4"
-                elif size == 8:
-                    fmt = "<u8"
+                fmt = f"<u{size}"
 
         elif data_type in v4c.STRING_TYPES:
             if channel_type == v4c.CHANNEL_TYPE_VALUE:
                 fmt = f"S{size}"
             else:
-                if size == 4:
-                    fmt = "<u4"
-                elif size == 8:
-                    fmt = "<u8"
+                fmt = f"<u{size}"
 
         elif data_type == v4c.DATA_TYPE_CANOPEN_DATE:
             fmt = "V7"
@@ -445,7 +439,7 @@ def fmt_to_datatype_v3(fmt, shape, array=False):
 
     """
     byteorder = fmt.byteorder
-    if byteorder == '=|':
+    if byteorder in '=|':
         byteorder = '<' if sys.byteorder == 'little' else '>'
     size = fmt.itemsize * 8
     kind = fmt.kind
