@@ -13,5 +13,5 @@ class ChannelGroupInfoWidget(Ui_ChannelGroupInfo, QtWidgets.QWidget):
 
         self.channel_group_label.setText(channel_group.metadata())
 
-        if hasattr(channel_group, 'acq_source') and channel_group.acq_source:
+        if hasattr(channel_group, "acq_source") and channel_group.acq_source:
             self.source_label.setText(channel_group.acq_source.metadata())
