@@ -105,7 +105,7 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
             )
             self.mdf = MDF(mdf_path)
 
-        elif file_name.suffix.lower() == ".zip":
+        elif file_name.suffix.lower() in (".zip", ".mf4z"):
             progress.setLabelText("Opening zipped MF4 file")
             from mfile import ZIP
 
@@ -2284,7 +2284,11 @@ class FileWidget(Ui_file_widget, QtWidgets.QWidget):
                 if name[1:] == (-1, -1)
             ]
 
-            sigs = self.mdf.select(signals_)
+            sigs = self.mdf.select(signals_,
+                ignore_value2text_conversions=self.ignore_value2text_conversions,
+                copy_master=False,
+                validate=True,
+            )
 
             for sig in sigs:
                 group, index = self.mdf.whereis(sig.name)[0]
