@@ -975,6 +975,7 @@ class _Plot(pg.PlotWidget):
                 stats["overall_rms"] = ""
                 stats["overall_start"] = fmt.format(sig.timestamps[0])
                 stats["overall_stop"] = fmt.format(sig.timestamps[-1])
+                stats["overall_std"] = ""
                 stats["unit"] = ""
                 stats["color"] = sig.color
                 stats["name"] = sig.name
@@ -1006,17 +1007,20 @@ class _Plot(pg.PlotWidget):
                 stats["selected_max"] = ""
                 stats["selected_average"] = ""
                 stats["selected_rms"] = ""
+                stats["selected_std"] = ""
                 stats["selected_delta"] = ""
                 stats["visible_min"] = ""
                 stats["visible_max"] = ""
                 stats["visible_average"] = ""
                 stats["visible_rms"] = ""
+                stats["visible_std"] = ""
                 stats["visible_delta"] = ""
             else:
                 stats["overall_min"] = fmt.format(sig.min)
                 stats["overall_max"] = fmt.format(sig.max)
                 stats["overall_average"] = sig.avg
                 stats["overall_rms"] = sig.rms
+                stats["overall_std"] = sig.std
                 stats["overall_start"] = sig.timestamps[0]
                 stats["overall_stop"] = sig.timestamps[-1]
                 stats["unit"] = sig.unit
@@ -1073,6 +1077,7 @@ class _Plot(pg.PlotWidget):
                             new_stats["selected_rms"] = np.sqrt(
                                 np.mean(np.square(cut.samples))
                             )
+                            new_stats["selected_std"] = np.std(cut.samples)
                             if cut.samples.dtype.kind in "ui":
                                 new_stats["selected_delta"] = fmt.format(
                                     int(float(cut.samples[-1]) - (cut.samples[0]))
@@ -1087,6 +1092,7 @@ class _Plot(pg.PlotWidget):
                             new_stats["selected_max"] = "n.a."
                             new_stats["selected_average"] = "n.a."
                             new_stats["selected_rms"] = "n.a."
+                            new_stats["selected_std"] = "n.a."
                             new_stats["selected_delta"] = "n.a."
 
                         sig._stats["range"] = (start, stop)
@@ -1102,6 +1108,7 @@ class _Plot(pg.PlotWidget):
                     stats["selected_max"] = ""
                     stats["selected_average"] = ""
                     stats["selected_rms"] = ""
+                    stats["selected_std"] = ""
                     stats["selected_delta"] = ""
 
                 (start, stop), _ = self.viewbox.viewRange()
@@ -1121,6 +1128,8 @@ class _Plot(pg.PlotWidget):
                         new_stats["visible_rms"] = np.sqrt(
                             np.mean(np.square(cut.samples))
                         )
+                        new_stats["visible_std"] = np.std(cut.samples)
+
                         if cut.samples.dtype.kind in "ui":
                             new_stats["visible_delta"] = int(cut.samples[-1]) - int(
                                 cut.samples[0]
@@ -1135,6 +1144,7 @@ class _Plot(pg.PlotWidget):
                         new_stats["visible_max"] = "n.a."
                         new_stats["visible_average"] = "n.a."
                         new_stats["visible_rms"] = "n.a."
+                        new_stats["visible_std"] = "n.a."
                         new_stats["visible_delta"] = "n.a."
 
                     sig._stats["visible"] = (start, stop)
@@ -1147,6 +1157,7 @@ class _Plot(pg.PlotWidget):
             stats["overall_max"] = "n.a."
             stats["overall_average"] = "n.a."
             stats["overall_rms"] = "n.a."
+            stats["overall_std"] = "n.a."
             stats["overall_start"] = "n.a."
             stats["overall_stop"] = "n.a."
             stats["unit"] = sig.unit
@@ -1174,6 +1185,7 @@ class _Plot(pg.PlotWidget):
                 stats["selected_max"] = "n.a."
                 stats["selected_average"] = "n.a."
                 stats["selected_rms"] = "n.a."
+                stats["selected_std"] = "n.a."
                 stats["selected_delta"] = "n.a."
 
             else:
@@ -1184,6 +1196,7 @@ class _Plot(pg.PlotWidget):
                 stats["selected_max"] = ""
                 stats["selected_average"] = "n.a."
                 stats["selected_rms"] = "n.a."
+                stats["selected_std"] = "n.a."
                 stats["selected_delta"] = ""
 
             (start, stop), _ = self.viewbox.viewRange()
@@ -1196,6 +1209,7 @@ class _Plot(pg.PlotWidget):
             stats["visible_max"] = "n.a."
             stats["visible_average"] = "n.a."
             stats["visible_rms"] = "n.a."
+            stats["visible_std"] = "n.a."
             stats["visible_delta"] = "n.a."
 
         sig._stats["fmt"] = fmt
@@ -1804,11 +1818,13 @@ class _Plot(pg.PlotWidget):
                     sig.max = np.nanmax(samples)
                     sig.avg = np.mean(samples)
                     sig.rms = np.sqrt(np.mean(np.square(samples)))
+                    sig.std = np.std(samples)
                 else:
                     sig.min = "n.a."
                     sig.max = "n.a."
                     sig.avg = "n.a."
                     sig.rms = "n.a."
+                    sig.std = "n.a."
 
                 sig.empty = False
 
@@ -1818,6 +1834,7 @@ class _Plot(pg.PlotWidget):
                 sig.max = "n.a."
                 sig.rms = "n.a."
                 sig.avg = "n.a."
+                sig.std = "n.a."
 
             axis = FormatedAxis("right", pen=color)
             if sig.conversion and hasattr(sig.conversion, "text_0"):
