@@ -4,6 +4,8 @@ from PyQt5 import QtWidgets
 from PyQt5 import QtCore
 import pandas as pd
 
+from traceback import format_exc
+
 from ..ui import resource_rc as resource_rc
 from ..ui.tabular_filter import Ui_TabularFilter
 
@@ -53,7 +55,7 @@ class TabularFilter(Ui_TabularFilter, QtWidgets.QWidget):
                             f"{column_name} requires an integer target value",
                         )
                 else:
-                    if self.as_hex:
+                    if self.as_hex[idx]:
                         try:
                             self._target = int(target, 16)
                             self.target.setText(f"0x{self._target:X}")
